pub struct FullPath(_);
Represents the full request path, returned by the full() filter.
full()
Get the &str representation of the request path.
&str
TypeId
self
Returns the argument unchanged.
Span
Instrumented
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
From<T> for U
Self
Subscriber
WithDispatch