pub struct Server<F, A, R> { /* private fields */ }Available on crate feature
server and docsrs only.Expand description
Implementations
Sourceimpl<F, R> Server<F, LazyTcp, R>
impl<F, R> Server<F, LazyTcp, R>
Sourcepub async fn run(self, addr: impl Into<SocketAddr>)
pub async fn run(self, addr: impl Into<SocketAddr>)
Binds and runs this server.
Panics
Panics if we are unable to bind to the provided address.
To handle bind failures, bind a listener and call incoming().
Sourcepub async fn bind(
self,
addr: impl Into<SocketAddr>,
) -> Server<F, TcpListener, R>
pub async fn bind( self, addr: impl Into<SocketAddr>, ) -> Server<F, TcpListener, R>
Binds this server.
Panics
Panics if we are unable to bind to the provided address.
To handle bind failures, bind a listener and call incoming().